@@ -10,7 +10,7 @@ class SetAction(argparse.Action):
         setattr(namespace, self.dest, set(values))
 
 
-def commandline_args(name: str = "fortls") -> argparse.ArgumentParser:
+def cli(name: str = "fortls") -> argparse.ArgumentParser:
     """Parses the command line arguments to the Language Server
 
     Returns
@@ -114,6 +114,8 @@ def commandline_args(name: str = "fortls") -> argparse.ArgumentParser:
         "--incl_suffixes",
         type=str,
         nargs="*",
+        default=set(),
+        action=SetAction,
         metavar="SUFFIXES",
         help=(
             "Consider additional file extensions to the default (default: "
